@@ -5,6 +5,7 @@ from .errors import UnmarshalError
 from .point import Point
 from .detail import Detail
 from .geochat import GeoChat
+from .takuser import TAKUser
 
 
 class Event:
@@ -72,17 +73,20 @@ class Event:
         if ret.etype is None:
             raise UnmarshalError("Event must have 'type' attribute")
 
-        for child in elm.iterchildren():
-            if child.tag == "point":
-                try:
+        try:
+            for child in elm.iterchildren():
+                if child.tag == "point":
                     ret.point = Point.from_elm(child)
-                except (TypeError, ValueError) as exc:
-                    raise UnmarshalError("Point parsing error") from exc
-            elif child.tag == "detail":
-                if ret.etype == "b-t-f":
-                    ret.detail = GeoChat.from_elm(child, event=ret)
-                else:
-                    ret.detail = Detail.from_elm(child, event=ret)
+                elif child.tag == "detail":
+                    d_tags = set([d_elm.tag for d_elm in child.iterchildren()])
+                    if TAKUser.is_type(d_tags):
+                        ret.detail = TAKUser.from_elm(child, uid=ret.uid)
+                    elif GeoChat.is_type(d_tags):
+                        ret.detail = GeoChat.from_elm(child)
+                    else:
+                        ret.detail = Detail.from_elm(child)
+        except (TypeError, ValueError, AttributeError) as exc:
+            raise UnmarshalError(f"Issue parsing {child.tag}") from exc
 
         return ret
 
