@@ -1,12 +1,14 @@
 import enum
 
 from lxml import etree
+from dateutil.parser import isoparse
 
 from .errors import UnmarshalError
 from .detail import Detail
 from .teams import Teams
 
 ALL_CHAT_ROOMS = "All Chat Rooms"
+GEOCHAT_TAGS = set(["__chat", "remarks", "link"])
 
 
 class ChatParents(enum.Enum):
@@ -23,8 +25,8 @@ class GeoChat(Detail):
     attempts to unify the field names and meanings.
     """
 
-    def __init__(self, event, elm):
-        super().__init__(event, elm)
+    def __init__(self, elm):
+        super().__init__(elm)
 
         self.chatroom = None  # detail/__chat.chatroom
         self.chat_parent = None  # detail/__chat.parent
@@ -35,6 +37,7 @@ class GeoChat(Detail):
         self.src_cs = None  # detail/__chat.senderCallsign
         self.src_marker = None  # detail/link.type
         self.message = None  # detail/remarks
+        self.message_ts = None  # detail/remarks.time
 
         # These fields are inferred
         # The UID (string) of the recipient (if an individual user, otherwise None)
@@ -49,18 +52,19 @@ class GeoChat(Detail):
                 ALL_CHAT_ROOMS,
                 self.message,
             )
-        elif self.dst_team:
+
+        if self.dst_team:
             return '<GeoChat src="%s", dst="%s", msg="%s">' % (
                 self.src_cs,
                 self.dst_team,
                 self.message,
             )
-        else:
-            return '<GeoChat src="%s", dst_uid="%s", msg="%s">' % (
-                self.src_cs,
-                self.dst_uid,
-                self.message,
-            )
+
+        return '<GeoChat src="%s", dst_uid="%s", msg="%s">' % (
+            self.src_cs,
+            self.dst_uid,
+            self.message,
+        )
 
     @property
     def broadcast(self):
@@ -68,7 +72,11 @@ class GeoChat(Detail):
         return self.chatroom == ALL_CHAT_ROOMS
 
     @staticmethod
-    def from_elm(elm, event=None):
+    def is_type(tags):
+        return GEOCHAT_TAGS.issubset(tags)
+
+    @staticmethod
+    def from_elm(elm):
         if elm.tag != "detail":
             raise UnmarshalError("Cannot create GeoChat from %s" % elm.tag)
 
@@ -82,7 +90,7 @@ class GeoChat(Detail):
         if None in [chat, chatgrp, remarks, link]:
             raise UnmarshalError("Detail does not contain GeoChat")
 
-        gch = GeoChat(event, elm)
+        gch = GeoChat(elm)
         gch.chat_parent = chat.get("parent")
         gch.group_owner = chat.get("groupOwner") == "true"
         gch.src_uid = link.get("uid")
@@ -97,6 +105,7 @@ class GeoChat(Detail):
             gch.dst_uid = chat.get("id")
 
         gch.message = remarks.text
+        gch.message_ts = isoparse(remarks.get("time")).replace(tzinfo=None)
 
         return gch
 
@@ -143,7 +152,7 @@ class GeoChat(Detail):
             attrib={
                 "source": rmk_src,
                 "to": dst_uid,
-                "time": self.event.time.isoformat(timespec="milliseconds") + "Z",
+                "time": self.message_ts.isoformat(timespec="milliseconds") + "Z",
             },
         )
         remarks.text = self.message
